==> xlr-application-pipelines-module-23.1.7-sources.jar: com/xebialabs/xlrelease/status/service/EndpointSetupDeploymentStatusService.scala <==
package com.xebialabs.xlrelease.status.service

import com.xebialabs.deployit.plugin.api.reflect.Type
import com.xebialabs.xlrelease.api.v1.ConfigurationApi
import com.xebialabs.xlrelease.domain.Configuration
import com.xebialabs.xlrelease.repository.ConfigurationRepository
import com.xebialabs.xlrelease.service.ConfigurationAutoconfigService
import com.xebialabs.xlrelease.status.webhook.events.StatusWebhookEventSource
import com.xebialabs.xlrelease.views.AutoconfigResponse
import com.xebialabs.xlrelease.webhooks.authentication.NoAuthentication
import com.xebialabs.xlrelease.webhooks.endpoint.WebhookEndpoint.PostWebhookEndpoint
import org.springframework.stereotype.Service

import java.util.UUID
import scala.jdk.CollectionConverters._

trait EndpointSetupDeploymentStatusService {
  def setupApplicationStatusWebhook(serverId: String, folderId: String): WebhookBasicSetup
}

@Service
class SetupApplicationStatusServiceImpl(
                                         configurationApi: ConfigurationApi,
                                         configurationAutoconfigService: ConfigurationAutoconfigService,
                                         configurationRepository: ConfigurationRepository,
                                       ) extends EndpointSetupDeploymentStatusService {

  override def setupApplicationStatusWebhook(serverId: String, folderId: String): WebhookBasicSetup = {

    val eventSources: List[StatusWebhookEventSource] = configurationRepository
      .findAllByTypeAndTitle[StatusWebhookEventSource](Type.valueOf(classOf[StatusWebhookEventSource]), null, folderId, folderOnly = true)
      .asScala.filter(_.sourceServer.getId == serverId).toList

    if (eventSources.nonEmpty) {
      WebhookBasicSetup(success = false, null, null, null, eventSources.head.getId)
    } else {
      val server: Configuration = configurationRepository.read(serverId)
      val webhookEndpoint: Configuration = createHttpEndpointForWebhook(folderId, server.getTitle)
      val statusWebhookSource: Configuration = createStatusWebhookSource(
        folderId,
        server.getTitle,
        webhookEndpoint,
        server)

      val autoconfigResponse: AutoconfigResponse = configurationAutoconfigService.autoconfigure(statusWebhookSource)
      WebhookBasicSetup(
        autoconfigResponse.getSuccess,
        autoconfigResponse.getMessage,
        autoconfigResponse.getDetails,
        autoconfigResponse.getUrl,
        statusWebhookSource.getId
      )

    }

  }

  private def createHttpEndpointForWebhook(folderId: String, title: String): Configuration = {

    val webhookEndpoint: PostWebhookEndpoint = Type.valueOf(classOf[PostWebhookEndpoint])
      .getDescriptor.newInstance("post-webhook-endpoint")

    webhookEndpoint.setTitle(title)
    webhookEndpoint.setFolderId(folderId)
    webhookEndpoint.setProperty("path", s"path-${UUID.randomUUID}")
    webhookEndpoint.setProperty("authentication", new NoAuthentication)

    configurationApi.addConfiguration(webhookEndpoint)
  }

  private def createStatusWebhookSource(folderId: String,
                                        title: String,
                                        eventSource: Configuration,
                                        sourceServer: Configuration): Configuration = {

    val statusWebhookEventSourceType: String = if (sourceServer.getType == Type.valueOf("xldeploy.XLDeployServer")) {
      "xldeploy.StatusWebhookEventSource"
    } else {
      "argocd.StatusWebhookEventSource"
    }

    val statusWebhookEventSource: StatusWebhookEventSource = Type.valueOf(statusWebhookEventSourceType)
      .getDescriptor.newInstance("status-event-webhook")
    statusWebhookEventSource.setTitle(title)
    statusWebhookEventSource.setFolderId(folderId)
    statusWebhookEventSource.setProperty("eventSource", eventSource)
    statusWebhookEventSource.setProperty("sourceServer", sourceServer)

    configurationApi.addConfiguration(statusWebhookEventSource)
  }
}

case class WebhookBasicSetup(success: Boolean,
                             message: String,
                             details: String,
                             url: String,
                             webhookSourceId: String)

==> xlr-application-pipelines-module-23.3.0-903.947-sources.jar: com/xebialabs/xlrelease/status/service/EndpointSetupDeploymentStatusService.scala <==
package com.xebialabs.xlrelease.status.service

import com.xebialabs.deployit.plugin.api.reflect.Type
import com.xebialabs.xlrelease.api.v1.ConfigurationApi
import com.xebialabs.xlrelease.domain.Configuration
import com.xebialabs.xlrelease.repository.ConfigurationRepository
import com.xebialabs.xlrelease.service.ConfigurationAutoconfigService
import com.xebialabs.xlrelease.status.webhook.configuration.StatusHttpConnection
import com.xebialabs.xlrelease.status.webhook.events.StatusWebhookEventSource
import com.xebialabs.xlrelease.views.AutoconfigResponse
import com.xebialabs.xlrelease.webhooks.authentication.NoAuthentication
import com.xebialabs.xlrelease.webhooks.endpoint.WebhookEndpoint.PostWebhookEndpoint
import org.springframework.stereotype.Service

import java.util.UUID
import scala.jdk.CollectionConverters._

trait EndpointSetupDeploymentStatusService {
  def setupApplicationStatusWebhook(serverId: String, folderId: String): WebhookBasicSetup
}

@Service
class SetupApplicationStatusServiceImpl(
                                         configurationApi: ConfigurationApi,
                                         configurationAutoconfigService: ConfigurationAutoconfigService,
                                         configurationRepository: ConfigurationRepository,
                                       ) extends EndpointSetupDeploymentStatusService {

  override def setupApplicationStatusWebhook(serverId: String, folderId: String): WebhookBasicSetup = {

    val eventSources: List[StatusWebhookEventSource] = configurationRepository
      .findAllByTypeAndTitle[StatusWebhookEventSource](Type.valueOf(classOf[StatusWebhookEventSource]), null, folderId, folderOnly = true)
      .asScala.filter(_.sourceServer.getId == serverId).toList

    if (eventSources.nonEmpty) {
      WebhookBasicSetup(success = false, null, null, null, eventSources.head.getId)
    } else {
      val server: StatusHttpConnection = configurationRepository.read[StatusHttpConnection](serverId)
      val webhookEndpoint: Configuration = createHttpEndpointForWebhook(folderId, server.getTitle)
      val statusWebhookSource: Configuration = createStatusWebhookSource(
        folderId,
        server.getTitle,
        webhookEndpoint,
        server)

      val autoconfigResponse: AutoconfigResponse = configurationAutoconfigService.autoconfigure(statusWebhookSource)
      WebhookBasicSetup(
        autoconfigResponse.getSuccess,
        autoconfigResponse.getMessage,
        autoconfigResponse.getDetails,
        autoconfigResponse.getUrl,
        statusWebhookSource.getId
      )

    }

  }

  private def createHttpEndpointForWebhook(folderId: String, title: String): Configuration = {

    val webhookEndpoint: PostWebhookEndpoint = Type.valueOf(classOf[PostWebhookEndpoint])
      .getDescriptor.newInstance("post-webhook-endpoint")

    webhookEndpoint.setTitle(title)
    webhookEndpoint.setFolderId(folderId)
    webhookEndpoint.setProperty("path", s"path-${UUID.randomUUID}")
    webhookEndpoint.setProperty("authentication", new NoAuthentication)

    configurationApi.addConfiguration(webhookEndpoint)
  }

  private def createStatusWebhookSource(folderId: String,
                                        title: String,
                                        eventSource: Configuration,
                                        sourceServer: StatusHttpConnection): Configuration = {
    val statusWebhookEventSourceType: String = sourceServer.getStatusWebhookEventSourceName

    val statusWebhookEventSource: StatusWebhookEventSource = Type.valueOf(statusWebhookEventSourceType)
      .getDescriptor.newInstance("status-event-webhook")
    statusWebhookEventSource.setTitle(title)
    statusWebhookEventSource.setFolderId(folderId)
    statusWebhookEventSource.setProperty("eventSource", eventSource)
    statusWebhookEventSource.setProperty("sourceServer", sourceServer)

    configurationApi.addConfiguration(statusWebhookEventSource)
  }
}

case class WebhookBasicSetup(success: Boolean,
                             message: String,
                             details: String,
                             url: String,
                             webhookSourceId: String)
